<?php
if ( !defined( 'ABSPATH' ) ) exit;

if ( !class_exists( 'fdmDashboard' ) ) {
/**
 * Class to handle plugin permissions
 *
 * @since 2.0.0
 */
class fdmDashboard {

	public $message;
	public $status = true;

	private $plugin_permissions;
	private $permission_level;

	public function __construct() {
		add_action( 'admin_menu', array( $this, 'add_dashboard_to_menu' ), 99 );
		if ( isset($_POST['FDM_Upgrade_To_Full']) ) { add_action( 'init', array( $this, 'check_upgrade_code' ) ); }
		if ( get_option( 'FDM_Trial_Happening' ) == 'Yes' ) { $this->check_trial_status(); }

		add_action( 'admin_enqueue_scripts',  array( $this, 'enqueue_scripts' ) );
	}

	public function add_dashboard_to_menu() {
		global $menu, $submenu;

		add_submenu_page( 
			'edit.php?post_type=fdm-menu', 
			'Dashboard', 
			'Dashboard', 
			'manage_options', 
			'fdm-dashboard', 
			array($this, 'display_dashboard_screen') 
		);

		//Find the dashboard page and move it to the top of the submenu
		foreach ( $submenu['edit.php?post_type=fdm-menu'] as $key => $sub_item ) {
			if ( $sub_item[0] == 'Dashboard' ) { $dashboard_key = $key; }
		}
		
		if ( isset( $dashboard_key ) ) {
			$submenu['edit.php?post_type=fdm-menu'][1] = $submenu['edit.php?post_type=fdm-menu'][$dashboard_key];
			unset($submenu['edit.php?post_type=fdm-menu'][$dashboard_key]);
		}
		ksort($submenu['edit.php?post_type=fdm-menu']);

		//Re-assign the submenu menu in preparation for changing the main menu link
		$submenu['edit.php?post_type=fdm-menu&page=fdm-dashboard'] = $submenu['edit.php?post_type=fdm-menu'];

		//Re-assign the menu page link to the dashboard submenu-page
		foreach ( $menu as $key => $menu_item ) {
			if ( $menu_item[2] == 'edit.php?post_type=fdm-menu' ) { $menu[$key][2] = 'edit.php?post_type=fdm-menu&page=fdm-dashboard'; }
		}

		//Change all of the submenu links so that they contain full URLs
		foreach ( $submenu['edit.php?post_type=fdm-menu&page=fdm-dashboard'] as $key => $sub_item ) {
			if ( strpos( $sub_item[2], '?' ) === false ) { $submenu['edit.php?post_type=fdm-menu&page=fdm-dashboard'][$key][2] = 'edit.php?post_type=fdm-menu&page=' . $submenu['edit.php?post_type=fdm-menu&page=fdm-dashboard'][$key][2]; }
		}
	}

	// Enqueues the admin script so that our hacky sub-menu opening function can run
	public function enqueue_scripts() {
		if ( isset( $_GET['post_type'] ) and ( $_GET['post_type'] == FDM_MENU_POST_TYPE or $_GET['post_type'] == FDM_MENUITEM_POST_TYPE ) ) {
			wp_enqueue_style( 'fdm-admin', FDM_PLUGIN_URL . '/assets/css/admin.css', array(), '2.0.0' );
			wp_enqueue_script( 'fdm-admin-js', FDM_PLUGIN_URL . '/assets/js/admin.js', array( 'jquery' ), '2.0.0', true );
		}
	}

	public function check_upgrade_code() {
		global $fdm_controller;

		$key = trim($_POST['Key']);
	
		if ($key == "FSP Trial" and !get_option("FDM_Trial_Happening")) {
			$this->message = __("Trial successfully started!", 'food-and-drink-menu');
	
			update_option("FDM_Trial_Expiry_Time", time() + (7*24*60*60));
			update_option("FDM_Trial_Happening", "Yes");

			update_option( "fdm-pre-permission-level", get_option( 'fdm-permission-level' ) );
			update_option( "fdm-permission-level", 2 );
			$fdm_controller->permissions->update_permissions();
	
			$Admin_Email = get_option('admin_email');
	
			$opts = array('http'=>array('method'=>"GET"));
			$context = stream_context_create($opts);
			$Response = file_get_contents("http://www.fivestarplugins.com/key-check/Register_Trial.php?Plugin=FDM&Admin_Email=" . $Admin_Email . "&Site=" . get_bloginfo('wpurl'), false, $context);
		}
		elseif ($key == "FSP Trial") {
			$this->status = false;
			$this->message = __('Trial has already been used.', 'food-and-drink-menu');
		}
		elseif (strlen($key) < 18 or strlen($key) > 22) {
			$this->status = false;
			$this->message = __('Invalid License Key', 'food-and-drink-menu');
		}
		elseif ($key != "FSP Trial") {
			$opts = array('http'=>array('method'=>"GET"));
			$context = stream_context_create($opts);
			$Response = unserialize(file_get_contents("http://www.fivestarplugins.com/key-check/FSP_FDM_KeyCheck.php?Key=" . $key . "&Site=" . get_bloginfo('wpurl'), false, $context));
			
			if ($Response['Message_Type'] == "Error") {
				$this->status = false;
				$this->message = $Response['Message'];
			}
			else {
				$this->message = $Response['Message'];
				update_option("FDM_Trial_Happening", "No");
				delete_option("FDM_Trial_Expiry_Time");

				update_option( "fdm-permission-level", 2 );
				$fdm_controller->permissions->update_permissions();
			}
		}

		add_action( 'admin_notices', array( $this, 'display_notice' ) );
	}

	public function check_trial_status() {
		if ( get_option( 'FDM_Trial_Expiry_Time' ) < time() ) {
			update_option( 'FDM_Trial_Happening', 'No');
			update_option( 'fdm-permission-level', get_option( 'fdm-pre-permission-level' ) );
			
			$fdm_controller->permissions->update_permissions();
		}
	}

	public function display_dashboard_screen() { 
		global $fdm_controller;

		$permission = $fdm_controller->permissions->check_permission( 'styling' );

		?>
		<div id="fdm-dashboard-content-area">

			<div id="fdm-dashboard-content-left">
		
				<?php if ( ! $permission or get_option("FDM_Trial_Happening") == "Yes") { ?>
					<div class="fdm-dashboard-new-widget-box ewd-widget-box-full">
						<div class="fdm-dashboard-new-widget-box-top">
							<form method="post" action="edit.php?post_type=fdm-menu&page=fdm-dashboard" class="fdm-dashboard-key-widget">
								<input class="fdm-dashboard-key-widget-input" name="Key" type="text" placeholder="<?php _e('Enter License Key Here', 'food-and-drink-menu'); ?>">
								<input class="fdm-dashboard-key-widget-submit" name="FDM_Upgrade_To_Full" type="submit" value="<?php _e('UNLOCK PREMIUM', 'food-and-drink-menu'); ?>">
								<div class="fdm-dashboard-key-widget-text">Don't have a key? Use the <a href="https://www.fivestarplugins.com/license-payment/?Selected=FDM&Quantity=1" target="_blank">Upgrade Now</a> button above to purchase and unlock all premium features.</div>
							</form>
						</div>
					</div>
				<?php } ?>
		
				<div class="fdm-dashboard-new-widget-box ewd-widget-box-full" id="fdm-dashboard-support-widget-box">
					<div class="fdm-dashboard-new-widget-box-top">Get Support<span id="fdm-dash-mobile-support-down-caret">&nbsp;&nbsp;&#9660;</span><span id="fdm-dash-mobile-support-up-caret">&nbsp;&nbsp;&#9650;</span></div>
					<div class="fdm-dashboard-new-widget-box-bottom">
						<ul class="fdm-dashboard-support-widgets">
							<li>
								<a href="https://www.youtube.com/channel/UCZPuaoetCJB1vZOmpnMxJNw/featured" target="_blank">
									<img src="<?php echo plugins_url( '../assets/img/ewd-support-icon-youtube.png', __FILE__ ); ?>">
									<div class="fdm-dashboard-support-widgets-text">YouTube Tutorials</div>
								</a>
							</li>
							<li>
								<a href="https://wordpress.org/plugins/food-and-drink-menu/#faq" target="_blank">
									<img src="<?php echo plugins_url( '../assets/img/ewd-support-icon-faqs.png', __FILE__ ); ?>">
									<div class="fdm-dashboard-support-widgets-text">Plugin FAQs</div>
								</a>
							</li>
							<li>
								<a href="https://wordpress.org/support/plugin/food-and-drink-menu" target="_blank">
									<img src="<?php echo plugins_url( '../assets/img/ewd-support-icon-forum.png', __FILE__ ); ?>">
									<div class="fdm-dashboard-support-widgets-text">Support Forum</div>
								</a>
							</li>
							<li>
								<a href="https://www.fivestarplugins.com/support-center/?Plugin=FDM" target="_blank">
									<img src="<?php echo plugins_url( '../assets/img/ewd-support-icon-documentation.png', __FILE__ ); ?>">
									<div class="fdm-dashboard-support-widgets-text">Documentation</div>
								</a>
							</li>
						</ul>
					</div>
				</div>
		
				<div class="fdm-dashboard-new-widget-box ewd-widget-box-full" id="fdm-dashboard-optional-table">
					<div class="fdm-dashboard-new-widget-box-top">Menus Summary<span id="fdm-dash-optional-table-down-caret">&nbsp;&nbsp;&#9660;</span><span id="fdm-dash-optional-table-up-caret">&nbsp;&nbsp;&#9650;</span></div>
					<div class="fdm-dashboard-new-widget-box-bottom">
						<table class='fdm-overview-table wp-list-table widefat fixed striped posts'>
							<thead>
								<tr>
									<th><?php _e("Title", 'EWD_ABCO'); ?></th>
									<th><?php _e("Sections", 'EWD_ABCO'); ?></th>
									<th><?php _e("Date", 'EWD_ABCO'); ?></th>
								</tr>
							</thead>
							<tbody>
								<?php
									$args = array(
										'post_type' => FDM_MENU_POST_TYPE,
										'posts_per_page' => 10
									);
		
									$menu_query = new WP_Query($args);
									$menus = $menu_query->get_posts();
		
									if (sizeOf($menus) == 0) {echo "<tr><td colspan='3'>" . __("No menus to display yet. Create an menu for it to be displayed here.", 'food-and-drink-menu') . "</td></tr>";}
									else {
										foreach ($menus as $menu) { 
											$post_meta = get_post_meta( $menu->ID );

											$col1 = !empty( $post_meta['fdm_menu_column_one'] ) ? array_filter( explode( ',', $post_meta['fdm_menu_column_one'][0] ) ) : array();
											$col2 = !empty( $post_meta['fdm_menu_column_two'] ) ? array_filter( explode( ',', $post_meta['fdm_menu_column_two'][0] ) ) : array();

										?>

											<tr>
												<td><a href='post.php?post=<?php echo $menu->ID;?>&action=edit'><?php echo $menu->post_title; ?></a></td>
												<td><?php 
													if ( !empty( $col1 ) || !empty( $col2 ) ) :
														$terms = get_terms( 'fdm-menu-section', array( 'include' => array_merge( $col1, $col2 ), 'hide_empty' => false ) );
														?>
										
														<div class="fdm-cols">
															<div class="fdm-col">
																<?php foreach( $col1 as $id ) : ?>
																	<?php $term = $this->get_term_from_array($terms, $id); ?>
																	<?php if ( !empty( $term ) ) : ?>
																		<a href="<?php echo esc_url( admin_url( 'edit-tags.php?action=edit&taxonomy=fdm-menu-section&tag_ID=' . $id . '&post_type=' . FDM_MENUITEM_POST_TYPE ) ); ?>">
																			<span class="fdm-term-count"><?php esc_html_e( $term->count ); ?></span>
																			<?php echo $term->name; ?>
																		</a>
																	<?php endif; ?>
																<?php endforeach; ?>
															</div>
															<div class="fdm-col">
																<?php foreach( $col2 as $id ) : ?>
																	<?php $term = $this->get_term_from_array($terms, $id); ?>
																	<?php if ( !empty( $term ) ) : ?>
																		<a href="<?php echo esc_url( admin_url( 'edit-tags.php?action=edit&taxonomy=fdm-menu-section&tag_ID=' . $id . '&post_type=' . FDM_MENUITEM_POST_TYPE ) ); ?>">
																			<span class="fdm-term-count"><?php esc_html_e( $term->count ); ?></span>
																			<?php echo $term->name; ?>
																		</a>
																	<?php endif; ?>
																<?php endforeach; ?>
															</div>
														</div>
										
													<?php endif;?>
												</td>
												<td><?php echo $menu->post_date; ?></td>
											</tr>
										<?php }
									}
								?>
							</tbody>
						</table>
					</div>
				</div>
		
				<?php /*<div class="fdm-dashboard-new-widget-box <?php echo ( ($hideReview != 'Yes' and $Ask_Review_Date < time()) ? 'ewd-widget-box-two-thirds' : 'ewd-widget-box-full' ); ?>">
					<div class="fdm-dashboard-new-widget-box-top">What People Are Saying</div>
					<div class="fdm-dashboard-new-widget-box-bottom">
						<ul class="fdm-dashboard-testimonials">
							<?php $randomTestimonial = rand(0,2);
							if($randomTestimonial == 0){ ?>
								<li id="fdm-dashboard-testimonial-one">
									<img src="<?php echo plugins_url( '../assets/img/dash-asset-stars.png', __FILE__ ); ?>">
									<div class="fdm-dashboard-testimonial-title">"Awesome. Just Awesome."</div>
									<div class="fdm-dashboard-testimonial-author">- @shizart</div>
									<div class="fdm-dashboard-testimonial-text">Thanks for this very well-made plugin. This works so well out of the box, I barely had to do ANYTHING to create an amazing FAQ accordion display... <a href="https://wordpress.org/support/topic/awesome-just-awesome-11/" target="_blank">read more</a></div>
								</li>
							<?php }
							if($randomTestimonial == 1){ ?>
								<li id="fdm-dashboard-testimonial-two">
									<img src="<?php echo plugins_url( '../assets/img/dash-asset-stars.png', __FILE__ ); ?>">
									<div class="fdm-dashboard-testimonial-title">"Absolutely perfect with great support"</div>
									<div class="fdm-dashboard-testimonial-author">- @isaac85</div>
									<div class="fdm-dashboard-testimonial-text">I tried several different FAQ plugins and this is by far the prettiest and easiest to use... <a href="https://wordpress.org/support/topic/absolutely-perfect-with-great-support/" target="_blank">read more</a></div>
								</li>
							<?php }
							if($randomTestimonial == 2){ ?>
								<li id="fdm-dashboard-testimonial-three">
									<img src="<?php echo plugins_url( '../assets/img/dash-asset-stars.png', __FILE__ ); ?>">
									<div class="fdm-dashboard-testimonial-title">"Perfect FAQ Plugin"</div>
									<div class="fdm-dashboard-testimonial-author">- @muti-wp</div>
									<div class="fdm-dashboard-testimonial-text">Works great! Easy to configure and to use. Thanks! <a href="https://wordpress.org/support/topic/perfect-faq-plugin/" target="_blank">read more</a></div>
								</li>
							<?php } ?>
						</ul>
					</div>
				</div> */ ?>
		
				<?php /* if($hideReview != 'Yes' and $Ask_Review_Date < time()){ ?>
					<div class="fdm-dashboard-new-widget-box ewd-widget-box-one-third">
						<div class="fdm-dashboard-new-widget-box-top">Leave a review</div>
						<div class="fdm-dashboard-new-widget-box-bottom">
							<div class="fdm-dashboard-review-ask">
								<img src="<?php echo plugins_url( '../assets/img/dash-asset-stars.png', __FILE__ ); ?>">
								<div class="fdm-dashboard-review-ask-text">If you enjoy this plugin and have a minute, please consider leaving a 5-star review. Thank you!</div>
								<a href="https://wordpress.org/plugins/ultimate-faqs/#reviews" class="fdm-dashboard-review-ask-button">LEAVE A REVIEW</a>
								<form action="admin.php?page=EWD-UFAQ-Options" method="post">
									<input type="hidden" name="hide_ufaq_review_box_hidden" value="Yes">
									<input type="submit" name="hide_ufaq_review_box_submit" class="fdm-dashboard-review-ask-dismiss" value="I've already left a review">
								</form>
							</div>
						</div>
					</div>
				<?php } */ ?>
		
				<?php if ( ! $permission or get_option("FDM_Trial_Happening") == "Yes" ) { ?>
					<div class="fdm-dashboard-new-widget-box ewd-widget-box-full" id="fdm-dashboard-guarantee-widget-box">
						<div class="fdm-dashboard-new-widget-box-top">
							<div class="fdm-dashboard-guarantee">
								<div class="fdm-dashboard-guarantee-title">14-Day 100% Money-Back Guarantee</div>
								<div class="fdm-dashboard-guarantee-text">If you're not 100% satisfied with the premium version of our plugin - no problem. You have 14 days to receive a FULL REFUND. We're certain you won't need it, though.</div>
							</div>
						</div>
					</div>
				<?php } ?>
		
			</div> <!-- left -->
		
			<div id="fdm-dashboard-content-right">
		
				<?php if ( ! $permission or get_option("FDM_Trial_Happening") == "Yes" ) { ?>
					<div class="fdm-dashboard-new-widget-box ewd-widget-box-full" id="fdm-dashboard-get-premium-widget-box">
						<div class="fdm-dashboard-new-widget-box-top">Get Premium</div>
						<?php if(get_option("FDM_Trial_Happening") == "Yes"){ 
							$trialExpireTime = get_option("FDM_Trial_Expiry_Time");
							$currentTime = time();
							$trialTimeLeft = $trialExpireTime - $currentTime;
							$trialTimeLeftDays = ( date("d", $trialTimeLeft) ) - 1;
							$trialTimeLeftHours = date("H", $trialTimeLeft);
							?>
							<div class="fdm-dashboard-new-widget-box-bottom">
								<div class="fdm-dashboard-get-premium-widget-trial-time">
									<div class="fdm-dashboard-get-premium-widget-trial-days"><?php echo $trialTimeLeftDays; ?><span>days</span></div>
									<div class="fdm-dashboard-get-premium-widget-trial-hours"><?php echo $trialTimeLeftHours; ?><span>hours</span></div>
								</div>
								<div class="fdm-dashboard-get-premium-widget-trial-time-left">LEFT IN TRIAL</div>
							</div>
						<?php } ?>
						<div class="fdm-dashboard-new-widget-box-bottom">
							<div class="fdm-dashboard-get-premium-widget-features-title"<?php echo ( get_option("FDM_Trial_Happening") == "Yes" ? "style='padding-top: 20px;'" : ""); ?>>GET FULL ACCESS WITH OUR PREMIUM VERSION AND GET:</div>
							<ul class="fdm-dashboard-get-premium-widget-features">
								<li>Multiple Layouts</li>
								<li>Custom Fields</li>
								<li>Dietary Icons</li>
								<li>Advanced Styling Options</li>
								<li>+ More</li>
							</ul>
							<a href="https://www.fivestarplugins.com/license-payment/?Selected=FDM&Quantity=1" class="fdm-dashboard-get-premium-widget-button" target="_blank">UPGRADE NOW</a>
							<?php if (!get_option("FDM_Trial_Happening")) { ?>
								<form method="post" action="edit.php?post_type=fdm-menu&page=fdm-dashboard">
									<input name="Key" type="hidden" value='FSP Trial'>
									<input name="FDM_Upgrade_To_Full" type="hidden" value='FDM_Upgrade_To_Full'>
									<button class="fdm-dashboard-get-premium-widget-button fdm-dashboard-new-trial-button">GET FREE 7-DAY TRIAL</button>
								</form>
							<?php } ?>
				</div>
					</div>
				<?php } ?>
		
				<!-- <div class="fdm-dashboard-new-widget-box ewd-widget-box-full">
					<div class="fdm-dashboard-new-widget-box-top">Other Plugins by Etoile</div>
					<div class="fdm-dashboard-new-widget-box-bottom">
						<ul class="fdm-dashboard-other-plugins">
							<li>
								<a href="https://wordpress.org/plugins/ultimate-product-catalogue/" target="_blank"><img src="<?php echo plugins_url( '../images/ewd-upcp-icon.png', __FILE__ ); ?>"></a>
								<div class="fdm-dashboard-other-plugins-text">
									<div class="fdm-dashboard-other-plugins-title">Product Catalog</div>
									<div class="fdm-dashboard-other-plugins-blurb">Enables you to display your business's products in a clean and efficient manner.</div>
								</div>
							</li>
							<li>
								<a href="https://wordpress.org/plugins/ultimate-reviews/" target="_blank"><img src="<?php echo plugins_url( '../images/ewd-urp-icon.png', __FILE__ ); ?>"></a>
								<div class="fdm-dashboard-other-plugins-text">
									<div class="fdm-dashboard-other-plugins-title">Ultimate Reviews</div>
									<div class="fdm-dashboard-other-plugins-blurb">Let visitors submit reviews and display them right in the tabbed page layout!</div>
								</div>
							</li>
						</ul>
					</div>
				</div> -->
		
			</div> <!-- right -->	
		
		</div> <!-- fdm-dashboard-content-area -->
		
		<?php if ( ! $permission or get_option("FDM_Trial_Happening") == "Yes" ) { ?>
			<div id="fdm-dashboard-new-footer-one">
				<div class="fdm-dashboard-new-footer-one-inside">
					<div class="fdm-dashboard-new-footer-one-left">
						<div class="fdm-dashboard-new-footer-one-title">What's Included in Our Premium Version?</div>
						<ul class="fdm-dashboard-new-footer-one-benefits">
							<li>Advanced Menu Layouts</li>
							<li>Custom Menu Fields</li>
							<li>Sorting and Filtering</li>
							<li>Dietary Icons</li>
							<li>Featured Item Flag</li>
							<li>Special/Discount Pricing</li>
							<li>Google Map Integration</li>
							<li>Free Lifetime Updates</li>
							<li>Advanced Styling Options</li>
						</ul>
					</div>
					<div class="fdm-dashboard-new-footer-one-buttons">
						<a class="fdm-dashboard-new-upgrade-button" href="https://www.fivestarplugins.com/license-payment/?Selected=FDM&Quantity=1" target="_blank">UPGRADE NOW</a>
					</div>
				</div>
			</div> <!-- fdm-dashboard-new-footer-one -->
		<?php } ?>	
		<div id="fdm-dashboard-new-footer-two">
			<div class="fdm-dashboard-new-footer-two-inside">
				<img src="<?php echo plugins_url( '../assets/img/fivestartextlogowithstar.png', __FILE__ ); ?>" class="fdm-dashboard-new-footer-two-icon">
				<div class="fdm-dashboard-new-footer-two-blurb">
					At Five Star Plugins, we build powerful, easy-to-use WordPress plugins with a focus on the restaurant, hospitality and business industries. With a modern, responsive look and a highly-customizable feature set, Five Star Plugins can be used as out-of-the-box solutions and can also be adapted to your specific requirements.
				</div>
				<ul class="fdm-dashboard-new-footer-two-menu">
					<li>SOCIAL</li>
					<li><a href="https://www.facebook.com/EtoileWebDesign/" target="_blank">Facebook</a></li>
					<li><a href="https://twitter.com/EtoileWebDesign" target="_blank">Twitter</a></li>
					<li><a href="https://www.etoilewebdesign.com/blog/" target="_blank">Blog</a></li>
				</ul>
				<ul class="fdm-dashboard-new-footer-two-menu">
					<li>SUPPORT</li>
					<li><a href="https://www.youtube.com/channel/UCZPuaoetCJB1vZOmpnMxJNw/featured" target="_blank">YouTube Tutorials</a></li>
					<li><a href="https://wordpress.org/support/plugin/food-and-drink-menu" target="_blank">Forums</a></li>
					<li><a href="https://www.fivestarplugins.com/support-center/?Plugin=FDM" target="_blank">Documentation</a></li>
					<li><a href="https://wordpress.org/plugins/food-and-drink-menu/#faq" target="_blank">FAQs</a></li>
				</ul>
			</div>
		</div> <!-- fdm-dashboard-new-footer-two -->
		
	<?php }

	public function get_term_from_array($terms, $term_id) {
		foreach ($terms as $term) {if ($term->term_id == $term_id) {return $term;}}

		return array();
	}

	public function display_notice() {
		if ( $this->status ) {
			echo "<div class='updated'><p>" . $this->message . "</p></div>";
		}
		else {
			echo "<div class='error'><p>" . $this->message . "</p></div>";
		}
	}
}
} // endif
